# ProjectCollaborator

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | 
**value** | [**ProjectCollaboratorValue**](ProjectCollaboratorValue.md) |  | 
**permission_level** | [**PermissionLevel**](PermissionLevel.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


